@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION='1.23';
+$VERSION='1.24';
 require Net::SMTP;
 use MIME::Base64;
 use Encode;
@@ -222,8 +222,8 @@ sub send
   $mail->{contenttype}=$properties{'-contenttype'} if defined $properties{'-contenttype'};
 
   $mail->{subject}='';
-#  $mail->{subject}=$properties{'-subject'} if defined $properties{'-subject'};
-  $mail->{subject}=encode("MIME-Q",$properties{'-subject'}) if defined $properties{'-subject'};
+  $mail->{subject}=$properties{'-subject'} if defined $properties{'-subject'};
+#  $mail->{subject}=encode("MIME-Q",$properties{'-subject'}) if defined $properties{'-subject'};
 
   $mail->{body}='';
   $mail->{body}=$properties{'-body'} if defined $properties{'-body'};
